summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccount.cpp')
-rw-r--r--kopete/libkopete/kopeteaccount.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/libkopete/kopeteaccount.cpp b/kopete/libkopete/kopeteaccount.cpp
index 11f668d8..0477ccd3 100644
--- a/kopete/libkopete/kopeteaccount.cpp
+++ b/kopete/libkopete/kopeteaccount.cpp
@@ -278,42 +278,42 @@ Kopete::MetaContact* Account::addContact( const TQString &contactId, const TQStr
}
else
{
// should we here add the contact to the tqparentContact if any?
kdDebug( 14010 ) << k_funcinfo << "Contact already exists" << endl;
}
return c->metaContact();
}
- MetaContact *tqparentContact = new MetaContact();
+ MetaContact *parentContact = new MetaContact();
if(!displayName.isEmpty())
- tqparentContact->setDisplayName( displayName );
+ parentContact->setDisplayName( displayName );
//Set it as a temporary contact if requested
if ( isTemporary )
- tqparentContact->setTemporary( true );
+ parentContact->setTemporary( true );
else
- tqparentContact->addToGroup( group );
+ parentContact->addToGroup( group );
if ( c )
{
- c->setMetaContact( tqparentContact );
+ c->setMetaContact( parentContact );
if ( mode == ChangeKABC )
{
kdDebug( 14010 ) << k_funcinfo << " changing KABC" << endl;
- KABCPersistence::self()->write( tqparentContact );
+ KABCPersistence::self()->write( parentContact );
}
}
else
{
- if ( !createContact( contactId, tqparentContact ) )
+ if ( !createContact( contactId, parentContact ) )
{
- delete tqparentContact;
+ delete parentContact;
return 0L;
}
}
- ContactList::self()->addMetaContact( tqparentContact );
- return tqparentContact;
+ ContactList::self()->addMetaContact( parentContact );
+ return parentContact;
}
bool Account::addContact(const TQString &contactId , MetaContact *tqparent, AddMode mode )
@@ -341,7 +341,7 @@ bool Account::addContact(const TQString &contactId , MetaContact *tqparent, AddM
}
else
{
// should we here add the contact to the tqparentContact if any?
kdDebug( 14010 ) << "Account::addContact: Contact already exists" << endl;
}
return false; //(the contact is not in the correct metacontact, so false)
@@ -278,42 +278,42 @@ Kopete::MetaContact* Account::addContact( const TQString &contactId, const TQStr
else
{
- // should we here add the contact to the tqparentContact if any?
+ // should we here add the contact to the parentContact if any?
kdDebug( 14010 ) << k_funcinfo << "Contact already exists" << endl;
}
@@ -341,7 +341,7 @@ bool Account::addContact(const TQString &contactId , MetaContact *tqparent, AddM
else
{
- // should we here add the contact to the tqparentContact if any?
+ // should we here add the contact to the parentContact if any?
kdDebug( 14010 ) << "Account::addContact: Contact already exists" << endl;
}